@@ -5,13 +5,14 @@ from arcor2 import DynamicParamTuple as DPT
 from arcor2 import rest
 from arcor2.data.common import ActionMetadata, Joint, Pose, StrEnum
 from arcor2.data.robot import RobotType
-from arcor2.object_types.abstract import Robot, RobotException, Settings
+from arcor2.object_types.abstract import Robot, RobotException
+
+from .fit_common_mixin import FitCommonMixin, UrlSettings
 
 
 @dataclass
-class DobotSettings(Settings):
+class DobotSettings(UrlSettings):
 
-    url: str
     port: str = "/dev/dobot"
 
 
@@ -26,19 +27,13 @@ class MoveType(StrEnum):
     LINEAR: str = "LINEAR"
 
 
-class AbstractDobot(Robot):
+class AbstractDobot(FitCommonMixin, Robot):
 
     robot_type = RobotType.SCARA
 
     def __init__(self, obj_id: str, name: str, pose: Pose, settings: DobotSettings) -> None:
         super(AbstractDobot, self).__init__(obj_id, name, pose, settings)
 
-    def _started(self) -> bool:
-        return rest.call(rest.Method.GET, f"{self.settings.url}/started", return_type=bool)
-
-    def _stop(self) -> None:
-        rest.call(rest.Method.PUT, f"{self.settings.url}/stop")
-
     def _start(self, model: str) -> None:
 
         if self._started():
@@ -46,13 +41,13 @@ class AbstractDobot(Robot):
 
         rest.call(
             rest.Method.PUT,
-            f"{self.settings.url}/start",
+            f"{self.settings.url}/state/start",
             params={"model": model, "port": self.settings.port},
             body=self.pose,
         )
 
     @property
-    def settings(self) -> DobotSettings:
+    def settings(self) -> DobotSettings:  # type: ignore
         return cast(DobotSettings, super(AbstractDobot, self).settings)
 
     def cleanup(self):
